@@ -1,11 +1,11 @@
 windex <-
-function(dat, tree, traits, focal=dat[,2],SE=TRUE){
+function(dat, tree, traits, focal=dat[,2],SE=TRUE,fossil=FALSE){
 
 if(is(tree,"phylo")==FALSE) stop('Tree must be of class phylo') #The tree is of the appropriate class
 
 if(all(tree$edge.length=="NULL")) stop('Tree must contain branch lengths')
  
-if(is.ultrametric(tree)!=TRUE) warning('Method is designed for ultrametric trees, your tree is not ultrametric so proceed with caution, if at all!') #
+if(is.ultrametric(tree)!=TRUE & fossil==FALSE) stop('Your tree is not ultrametric, so if this is intentional make sure you set fossil=TRUE') #
  
 if (is.vector(dat[,traits]) ==  TRUE) if(is.numeric(dat[,traits]) != TRUE) stop("Trait data must be numeric")
 if (is.vector(dat[,traits]) !=  TRUE) for (i in 1:length(dat[,traits])){
@@ -36,6 +36,11 @@ dij<-as.matrix(dist(data.w, method = "euclidean",diag=T,upper=T)) #calculate mat
 Tree1<-tree
 Tree1$edge.length<-Tree1$edge.length/max(nodeHeights(Tree1))
       pij<-vcv(Tree1) #shared proportional distance 
+	if(fossil==TRUE) {
+	cophenmat<-1-(cophenetic.phylo(Tree1)/2)
+	cophenmat[which(round(cophenmat,digits=10)!=round(pij,digits=10))]<-1-cophenmat[which(round(cophenmat,digits=10)!=round(pij,digits=10))]
+	pij<-cophenmat
+	}
       dij.<-dij/(1-log(pij+0.01)) #calculate corrected phenotypic distance matrix
 da<-mean(dij.)
 df<-mean(dij.[which(focal==1),which(focal==1)])
@@ -55,6 +60,11 @@ options(warn=+1) #turn warnings back on
 Tree1<-tree
 Tree1$edge.length<-Tree1$edge.length/max(nodeHeights(Tree1))
      pij<-vcv(Tree1) #shared proportional distance 
+     	if(fossil==TRUE) {
+	cophenmat<-1-(cophenetic.phylo(Tree1)/2)
+	cophenmat[which(round(cophenmat,digits=10)!=round(pij,digits=10))]<-1-cophenmat[which(round(cophenmat,digits=10)!=round(pij,digits=10))]
+	pij<-cophenmat
+	}
      dij.J<-dijJ/(1-log(pij+0.01)) #calculate corrected phenotypic distance matrix
 daJ<-mean(dij.J,na.rm = TRUE)
 dfJ<-mean(dij.J[which(focal==1),which(focal==1)],na.rm = TRUE)
